Called by Match the check whether a condition matches. Used to create custom methods for matching.
match_cond(cond, x, do, ...)match condition
object being matched
return expression associated with the condition. If cond is matched with x, then do
should be evaluated and returned in a list with TRUE: list(TRUE, eval(do)).
arguments passed to evaluation
FALSE if no match, or a list containing TRUE and the evaluated expression
See the Match details for explanations about provided methods.